@@ -16,7 +16,7 @@ NiceTreePlot <- function(ct, inner_plots = FALSE, cex = 0.8, justmin = 15) {
          ep_args = list(justmin = justmin))
   }
   
-  if(inner_plots & is.factor(Y)) {
+   else if(inner_plots & is.factor(Y)) {
     plot(ct,
          inner_panel = partykit::node_barplot(ct, mainlab = getvar, id = FALSE, beside = TRUE, gp = grid::gpar(cex=0.7)),
          terminal_panel = partykit::node_barplot(ct, id = FALSE, beside = TRUE),
@@ -24,7 +24,7 @@ NiceTreePlot <- function(ct, inner_plots = FALSE, cex = 0.8, justmin = 15) {
          ep_args = list(justmin = justmin))
   }
   
-  if(!inner_plots & is.numeric(Y)) {
+  else if(!inner_plots & is.numeric(Y)) {
     plot(ct,
          inner_panel = partykit::node_inner(ct, id = FALSE, pval = FALSE),
          terminal_panel = partykit::node_boxplot(ct, id = FALSE),
@@ -32,11 +32,28 @@ NiceTreePlot <- function(ct, inner_plots = FALSE, cex = 0.8, justmin = 15) {
          ep_args = list(justmin = justmin))
   }
   
-  if(inner_plots & is.numeric(Y)) {
+  else if(inner_plots & is.numeric(Y)) {
     plot(ct,
          inner_panel = partykit::node_boxplot(ct, mainlab = getvar, id = FALSE, gp = grid::gpar(cex = 0.7)),
          terminal_panel=partykit::node_boxplot(ct, id = FALSE),
          gp = grid::gpar(cex = cex),
          ep_args = list(justmin = justmin))
   }
-}
\ No newline at end of file
+  
+  else if(!inner_plots & is.data.frame(Y)) {
+    plot(ct,
+         inner_panel = partykit::node_inner(ct, id = FALSE, pval = FALSE),
+         terminal_panel = partykit::node_mvar(ct, id = FALSE),
+         gp = grid::gpar(cex = cex),
+         ep_args = list(justmin = justmin))
+  }
+  
+  else if(inner_plots & is.data.frame(Y)) {
+    plot(ct,
+         inner_panel = partykit::node_mvar(ct, mainlab = getvar, id = FALSE, gp = grid::gpar(cex = 0.7)),
+         terminal_panel=partykit::node_mvar(ct, id = FALSE),
+         gp = grid::gpar(cex = cex),
+         ep_args = list(justmin = justmin))
+  }
+  
+}
